drivers Package — pwman3 0.6 documentation

### Navigation

- index
- modules |
- pwman3 0.6 documentation »

# drivers Package

## `sqlite` Module

SQLite Database implementation.

class `pwman.data.drivers.sqlite.` `SQLite`(filename, dbformat=0.6)

  Bases: `pwman.data.database.Database`

  classmethod `check_db_version`(fname)

    check the database version.

  `editnode`(nid, **kwargs)
  `getnodes`(ids)

    get nodes as raw ciphertext

  `removenodes`(nids)
  `savekey`(key)

### Navigation

- index
- modules |
- pwman3 0.6 documentation »